@@ -3,10 +3,8 @@ import colorlog
 import datetime
 import logging
 import os
-import subprocess
-import sys
-import tempfile
-from acom_music_box import MusicBox, Examples, __version__
+from acom_music_box import MusicBox, Examples, __version__, DataOutput, PlotOutput
+from acom_music_box.utils import get_available_units
 
 
 def format_examples_help(examples):
@@ -32,7 +30,10 @@ def parse_arguments():
     parser.add_argument(
         '-o', '--output',
         type=str,
-        help='Path to save the output file, including the file name. If not provided, result will be printed to the console.'
+        action="append",
+        help=("Path to save the output file, including the file name."
+              + "\nIf not provided, result will be printed to the console."
+              + "\nUse the file extension to specify the output format: .csv or .nc (NetCDF)")
     )
     parser.add_argument(
         '-v', '--verbose',
@@ -53,7 +54,16 @@ def parse_arguments():
     parser.add_argument(
         '--plot',
         type=str,
-        help='Plot a comma-separated list of species if gnuplot is available (e.g., CONC.A,CONC.B).'
+        action='append',
+        help='Plot a comma-separated list of species (e.g., CONC.A,CONC.B).'
+    )
+
+    parser.add_argument(
+        '--plot-output-unit',
+        type=str,
+        choices=get_available_units(),
+        default='mol m-3',
+        help='Specify the output unit for plotting concentrations.'
     )
     return parser.parse_args()
 
@@ -83,42 +93,6 @@ def setup_logging(verbosity, color_output):
     logging.basicConfig(level=log_level, handlers=[console_handler])
 
 
-def plot_with_gnuplot(data, species_list):
-    # Prepare columns and data for plotting
-    columns = ['time'] + species_list
-    data_to_plot = data[columns]
-
-    data_csv = data_to_plot.to_csv(index=False)
-
-    try:
-        with tempfile.NamedTemporaryFile(delete=False, suffix='.csv') as data_file:
-            data_file.write(data_csv.encode())
-            data_file_path = data_file.name
-
-        plot_commands = ',\n\t'.join(
-            f"'{data_file_path}' using 1:{i+2} with lines title '{species}'" for i,
-            species in enumerate(species_list))
-
-        gnuplot_command = f"""
-        set datafile separator ",";
-        set terminal dumb size 120,25;
-        set xlabel 'Time';
-        set ylabel 'Value';
-        set title 'Time vs Species';
-        plot {plot_commands}
-        """
-
-        subprocess.run(['gnuplot', '-e', gnuplot_command], check=True)
-    except FileNotFoundError:
-        logging.critical("gnuplot is not installed. Skipping plotting.")
-    except subprocess.CalledProcessError as e:
-        logging.error(f"Error occurred while plotting: {e}")
-    finally:
-        # Clean up the temporary file
-        if data_file_path:
-            os.remove(data_file_path)
-
-
 def main():
     start = datetime.datetime.now()
 
@@ -139,35 +113,30 @@ def main():
     else:
         musicBoxConfigFile = args.config
 
-    musicBoxOutputPath = args.output
-    plot_species_list = args.plot.split(',') if args.plot else None
-
     if not musicBoxConfigFile:
         error = "Configuration file is required."
-        print(error)
         logger.error(error)
-        sys.exit(1)
+        raise RuntimeError(error)
 
     # Create and load a MusicBox object
     myBox = MusicBox()
     logger.debug(f"Configuration file = {musicBoxConfigFile}")
     myBox.loadJson(musicBoxConfigFile)
 
-    result = myBox.solve(musicBoxOutputPath)
+    result = myBox.solve(callback=None)
 
-    if musicBoxOutputPath is None:
-        print(result.to_csv(index=False))
+    # Create an instance of DataOutput for multiple output formats.
+    dataOutput = DataOutput(result, args)
+    dataOutput.output()
 
-    if plot_species_list:
-        # Prepare data for plotting
-        plot_with_gnuplot(result, plot_species_list)
+    # Create an instance of PlotOutput
+    plotOutput = PlotOutput(result, args)
+    plotOutput.plot()
 
     end = datetime.datetime.now()
     logger.info(f"End time: {end}")
     logger.info(f"Elapsed time: {end - start} seconds")
 
-    sys.exit(0)
-
 
 if __name__ == "__main__":
     main()
